/// <reference types="node" resolution-mode="require"/>
import { BufferReader } from '@aztec/foundation/serialize';
import { type Fr } from '../fields/fields.js';
/**
 * A class representing a hash.
 */
export declare class BaseHashType {
    /**
     * The buffer containing the hash.
     */
    buffer: Buffer;
    /**
     * The size of the hash in bytes.
     */
    static SIZE: number;
    /**
     * HashType with value zero.
     */
    static ZERO: BaseHashType;
    constructor(
    /**
     * The buffer containing the hash.
     */
    buffer: Buffer);
    /**
     * Returns the raw buffer of the hash.
     * @returns The buffer containing the hash.
     */
    toBuffer(): Buffer;
    /**
     * Creates a HashType from a buffer.
     * @param buffer - The buffer to create from.
     * @returns A new HashType object.
     */
    static fromBuffer(buffer: Buffer | BufferReader): BaseHashType;
    /**
     * Checks if this hash and another hash are equal.
     * @param hash - A hash to compare with.
     * @returns True if the hashes are equal, false otherwise.
     */
    equals(hash: BaseHashType): boolean;
    /**
     * Returns true if this hash is zero.
     * @returns True if this hash is zero.
     */
    isZero(): boolean;
    /**
     * Convert this hash to a hex string.
     * @returns The hex string.
     */
    toString(): string;
    /**
     * Convert this hash to a big int.
     * @returns The big int.
     */
    toBigInt(): bigint;
    /**
     * Creates a tx hash from a bigint.
     * @param hash - The tx hash as a big int.
     * @returns The HashType.
     */
    static fromBigInt(hash: bigint): BaseHashType;
    static fromField(hash: Fr): BaseHashType;
    /**
     * Converts this hash from a buffer of 28 bytes.
     * Verifies the input is 28 bytes.
     * @param buffer - The 28 byte buffer to construct from.
     * @returns A HashType created from the input buffer with 4 bytes 0 padding at the front.
     */
    static fromBuffer28(buffer: Buffer): BaseHashType;
    /**
     * Converts a string into a HashType object.
     * @param str - The TX hash in string format.
     * @returns A new HashType object.
     */
    static fromString(str: string): BaseHashType;
    /**
     * Generates a random HashType.
     * @returns A new HashType object.
     */
    static random(): BaseHashType;
}
//# sourceMappingURL=index.d.ts.map